==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/eu.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Jarduera",
    "Personal activity feed for %s" : "%sen jarduera jario pertsonala",
    "Your feed URL is invalid" : "Zure jarioaren URL-a ez da zuzena",
    "Your settings have been updated." : "Zure ezarpenak eguneratu dira.",
    "Mail" : "Posta",
    "Stream" : "Jarioa",
    "Activities" : "Jarduerak",
    "Error loading activities" : "Errorea jarduerak kargatzen",
    "No activities" : "Ez dago jarduerarik",
    "There are no events for this filter" : "Ez dago ekitaldirik iragazki honetarako",
    "Activity notification" : "Jarduera jakinarazpenak",
    "All Activities" : "Jarduera guztiak",
    "Activities by you" : "Zure jarduerak",
    "Activities by others" : "Besteen jarduerak",
    "\"remote user\"" : "\"urruneko erabiltzailea\"",
    "in %s" : "%s-an",
    "%s and %s" : "%s eta %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s eta <strong %s>%n gehiago</strong>","%s eta <strong %s>%n gehiago</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s eta %n gehiago","%s eta %n gehiago"],
    "Hello %s," : "Kaixo %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* eta %n gehiago","* eta %n gehiago"],
    "Notifications" : "Jakinarazpenak",
    "List your own actions in the stream" : "Zerrendatu zure jarduerak jarioan",
    "Notify about your own actions via email" : "Jakinarazi zeure jarduerak posta bidez",
    "You need to set up your email address before you can receive notification emails." : "Zure epostaren  zehaztu behar duzu jakinarazpen epostak jaso aurretik.",
    "Send emails:" : "Bidali epostak:",
    "Hourly" : "Orduro",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "Activity feed" : "Jarduera jarioa",
    "Enable RSS feed" : "Gaitu RSS jarioa",
    "No activity yet" : "Oraindik ez dago jarduerarik",
    "No more events to load" : "Ez dago kargatzeko gertaera gehiagorik",
    "Files" : "Fitxategiak",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s eta <strong class=\"has-tooltip\" title=\"%s\">%n gehiago</strong>","%s eta <strong class=\"has-tooltip\" title=\"%s\">%n gehiago</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/eu.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Jarduera",
    "Personal activity feed for %s" : "%sen jarduera jario pertsonala",
    "Your feed URL is invalid" : "Zure jarioaren URL-a ez da zuzena",
    "Your settings have been updated." : "Zure ezarpenak eguneratu dira.",
    "Mail" : "Posta",
    "Stream" : "Jarioa",
    "Activities" : "Jarduerak",
    "Error loading activities" : "Errorea jarduerak kargatzen",
    "No activities" : "Ez dago jarduerarik",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Isuri honek gehiketak, aldaketak eta partekatzeak bezalako gertaerak erakusten ditu",
    "There are no events for this filter" : "Ez dago ekitaldirik iragazki honetarako",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "\"remote user\"" : "\"urruneko erabiltzailea\"",
    "Activity notification" : "Jarduera jakinarazpenak",
    "All Activities" : "Jarduera guztiak",
    "Activities by you" : "Zure jarduerak",
    "Activities by others" : "Besteen jarduerak",
    "%s and %s" : "%s eta %s",
    "Hello %s," : "Kaixo %s,",
    "You are receiving this email because the following things happened at %s" : "Posta elektroniko hau jaso duzu %s-n hurrengo gertaerak egon direlako",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* eta %n gehiago","* eta %n gehiago"],
    "List your own actions in the stream" : "Zerrendatu zure jarduerak jarioan",
    "Notify about your own actions via email" : "Jakinarazi zeure jarduerak posta bidez",
    "You need to set up your email address before you can receive notification emails." : "Zure epostaren  zehaztu behar duzu jakinarazpen epostak jaso aurretik.",
    "Send emails:" : "Bidali epostak:",
    "Hourly" : "Orduro",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "Activity feed" : "Jarduera jarioa",
    "Enable RSS feed" : "Gaitu RSS jarioa",
    "No activity yet" : "Oraindik ez dago jarduerarik",
    "No more events to load" : "Ez dago kargatzeko gertaera gehiagorik",
    "Files" : "Fitxategiak"
},
"nplurals=2; plural=(n != 1);");
